@@ -39,8 +39,9 @@ hashtag_changesets = {}
 countries_changesets = {}
 
 # read the GeoJSON file
-working_dir = os.path.realpath(os.path.dirname(__file__))
-countries_df = gpd.read_file(os.path.join(working_dir, "data/countries_un.geojson"))
+countries_df = gpd.read_file(
+    "https://raw.githubusercontent.com/kshitijrajsharma/OSMSG/master/data/countries_un.geojson"
+)
 
 
 def collect_changefile_stats(user, uname, changeset, version, tags, osm_type):
